Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(205)

Unified Diff: sync/sessions/sync_session.cc

Issue 10832286: sync: Introduce control data types (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sync/sessions/sync_session.cc
diff --git a/sync/sessions/sync_session.cc b/sync/sessions/sync_session.cc
index ee296682111b4449f3c6f9e2b59b20ea579f5354..e65466bece1879858a066a69b19f2f4ac49e73a4 100644
--- a/sync/sessions/sync_session.cc
+++ b/sync/sessions/sync_session.cc
@@ -27,9 +27,11 @@ std::set<ModelSafeGroup> ComputeEnabledGroups(
it != routing_info.end(); ++it) {
enabled_groups.insert(it->second);
}
// GROUP_PASSIVE is always enabled, since that's the group that
// top-level folders map to.
enabled_groups.insert(GROUP_PASSIVE);
+ enabled_groups.insert(GROUP_CONTROL);
if (DCHECK_IS_ON()) {
// We sometimes create dummy SyncSession objects (see
// SyncScheduler::InitialSnapshot) so don't check in that case.
@@ -27,9 +27,11 @@ std::set<ModelSafeGroup> ComputeEnabledGroups(
enabled_groups.insert(it->second);
}
- // GROUP_PASSIVE is always enabled, since that's the group that
- // top-level folders map to.
+ // GROUP_PASSIVE is always enabled, since that's the group that top-level
+ // folders map to.
+ // GROUP_CONTROL manages some meta-data types that are always enabled.
enabled_groups.insert(GROUP_PASSIVE);

Powered by Google App Engine
This is Rietveld 408576698